Learn R Programming

MAGNAMWAR (version 2.0.4)

CalculatePrincipalCoordinates: Show Principal Components Breakdown

Description

Function to show Principal Components statistics based on the OrthoMCL presence absence groupings.

Usage

CalculatePrincipalCoordinates(mcl_data)

Arguments

mcl_data

output of FormatAfterOrtho --list of 2 things-- 1: binary matrix indicating the presence / absence of genes in each OG and 2: vector of names of OGs

Value

returns a named list of principal components and accompanying proportion of variance for each

Examples

Run this code
# NOT RUN {
CalculatePrincipalCoordinates(after_ortho_format)
# }

Run the code above in your browser using DataLab