powered by
Function to show Principal Components statistics based on the OrthoMCL presence absence groupings.
CalculatePrincipalCoordinates(mcl_data)
output of FormatAfterOrtho --list of 2 things-- 1: binary matrix indicating the presence / absence of genes in each OG and 2: vector of names of OGs
returns a named list of principal components and accompanying proportion of variance for each
# NOT RUN { CalculatePrincipalCoordinates(after_ortho_format) # }
Run the code above in your browser using DataLab